--[[
Name: LibSQL-1.0
Revision: $Rev: 1 $
Author(s): Humbedooh
Description: SQL library for Lua
Optional dependencies: LibStub
License: All Sporks Reserved!
]]
-----------------------------------------------------------------------

local LIBSQL = "LibSQL-1.0"
local LIBSQL_MINOR = tonumber(("$Rev: 01 $"):match("(%d+)")) or 10000;
local LibSQL = false;
if LibStub then
    LibSQL = LibStub:NewLibrary(LIBSQL, LIBSQL_MINOR)
    _G.LibSQL = LibSQL;
else
    if not _G.LibSQL or (type(_G.LibSQL) == "table" and _G.LibSQL.rev < LIBSQL_MINOR) then
        _G.LibSQL = {rev = LIBSQL_MINOR};
    end
    LibSQL = _G.LibSQL;
end
if not LibSQL then return end

LibSQL_Reserved = { 'CREATE', 'DELETE', 'DROP', 'TRUNCATE', 'SELECT', 'UPDATE', 'INSERT', 'ORDER' };
LibSQL_Ignored = {'TABLE', 'BY', 'INTO' };
LibSQL_Resource = {};
function LibSQL:Parse(arg)
    local db = self;
    if type(arg) ~= "string" or type(db) ~= "table" then return end
    local cmd = arg:match("^%s*(%a+)%s");
    if cmd then cmd = cmd:upper(); end
    print(cmd)
end

local function LibSQL_Resource_Next(res)
    res._pointer = (res._pointer or 0)+1;
    local entry = res._entries[res._pointer];
    if not entry then return nil end
    return unpack(entry or {});
end

local function LibSQL_Resource_Next_Arrayed(res)
    res._pointer = (res._pointer or 0)+1;
    local entry = res._entries[res._pointer];
    if not entry then return nil end
    return entry or {};
end

local function LibSQL_Resource_Next_Objectified(res)
    res._pointer = (res._pointer or 0)+1;
    local entry = res._entries[res._pointer];
    local obj = {};
    local f = res._fields;
    if not entry then return nil end
    for n = 1, #f do
        obj[f[n]] = entry[n];
    end
    return obj;
end
function LibSQL_Resource:Rewind() self._pointer = nil end
function LibSQL_Resource:Seek(num) self._pointer = tonumber(num) return self._pointer end
function LibSQL_Resource:Rows() return #self._entries end
function LibSQL_Resource:Fetch() return LibSQL_Resource_Next, self, nil end
function LibSQL_Resource:FetchObject() return LibSQL_Resource_Next_Objectified, self, nil end
function LibSQL_Resource:FetchArray() return LibSQL_Resource_Next_Arrayed, self, nil end

function LibSQL_Resource:New()
    local res = {};
    res._fields =   {};
    res._entries =  {}
    res._pointer = nil;
    res.Fetch =             LibSQL_Resource.Fetch;
    res.FetchObject =       LibSQL_Resource.FetchObject;
    res.FetchArray =        LibSQL_Resource.FetchArray;
    res.Rewind =            LibSQL_Resource.Rewind;
    res.Seek =              LibSQL_Resource.Seek;
    res.Rows =              LibSQL_Resource.Rows;
    return res;
end

function LibSQL:Open(db)
    db.Execute = LibSQL.Execute;
    return db;
end

function LibSQL:New() return LibSQL:Open({_tables = {}}) end

--[[

local db = LibSQL_Resource:New();
print("got", db:Rows(), "results!");
for a,b,c,d in db:FetchObject() do
    print(a.name, a.level)
end

]]--
